Expects raw source code and an include path (in the form "../include/filename.h")
This will do nothing and return code if the include statement already exists, otherwise
it will insert it at the end of all the include statements
Passing the below list to this function would return 3 (gets the next token, not the current token)
[object-token-curr, whitespace, whitespace, object-token-next]